aboutsummaryrefslogtreecommitdiffstats
path: root/server/sonar-web/config
diff options
context:
space:
mode:
authorGrégoire Aubert <gregoire.aubert@sonarsource.com>2019-09-19 11:42:06 +0200
committerSonarTech <sonartech@sonarsource.com>2019-09-30 20:21:07 +0200
commit981c82950bc89af49b21a07359fdcb2f28483ab7 (patch)
treebc3ff6ea99e0b0f1d6d4d1216e0d458b59f003f7 /server/sonar-web/config
parentf4bf76e488ab3d48cb12295d2aad77d9cf61cfb0 (diff)
downloadsonarqube-981c82950bc89af49b21a07359fdcb2f28483ab7.tar.gz
sonarqube-981c82950bc89af49b21a07359fdcb2f28483ab7.zip
Move from styled-components to @emotion
Diffstat (limited to 'server/sonar-web/config')
-rw-r--r--server/sonar-web/config/webpack.config.js5
1 files changed, 2 insertions, 3 deletions
diff --git a/server/sonar-web/config/webpack.config.js b/server/sonar-web/config/webpack.config.js
index 6bb41cf3468..955e4cc2c37 100644
--- a/server/sonar-web/config/webpack.config.js
+++ b/server/sonar-web/config/webpack.config.js
@@ -65,9 +65,8 @@ module.exports = ({ production = true, release = false }) => {
// import from 'Docs/foo.md' is rewritten to import from 'sonar-docs/src/foo.md'
alias: {
Docs: path.resolve(__dirname, '../../sonar-docs/src'),
- // This avoid having multi instance of styled component when developing with yarn link on sonar-ui-common
- // See https://www.styled-components.com/docs/faqs#how-can-i-fix-issues-when-using-npm-link-or-yarn-link
- 'styled-components': path.resolve(__dirname, '../node_modules/styled-components'),
+ // This avoid having multi instance of @emotion when developing with yarn link on sonar-ui-common
+ '@emotion': path.resolve(__dirname, '../node_modules/@emotion'),
// This avoid having multi instance of react when developing with yarn link on sonar-ui-common
// See https://reactjs.org/warnings/invalid-hook-call-warning.html
react: path.resolve(__dirname, '../node_modules/react'),